@@ -9,7 +9,7 @@ use Encode      qw();
 use Carp        qw(croak);
 use base        qw(Text::Markdown);
 
-our $VERSION   = '1.0.28';
+our $VERSION   = '1.0.29';
 our @EXPORT_OK = qw(markdown);
 
 =head1 NAME
@@ -50,7 +50,10 @@ as headers, *emphasis*, code blocks, blockquotes, and links.
 Markdown's syntax is designed not as a generic markup language, but
 specifically to serve as a front-end to (X)HTML. You can use span-level
 HTML tags anywhere in a Markdown document, and you can use block level
-HTML tags (like <div> and <table> as well).
+HTML tags (C<< <div> >>, C<< <table> >> etc.). Note that by default
+Markdown isn't interpreted in HTML block-level elements, unless you add
+a C<markdown=1"> attribute to the element. See L<Text::Markdown> for 
+details.
 
 This module implements the MultiMarkdown markdown syntax extensions from:
 
